#' @keywords internal
"_PACKAGE"

#' @name selfX
#' @title s-X-AIPI self-X Data Exploration in R: A short introduction
#' @description
#'
#' "selfX" R package includes the implementation of several functions to
#' perform data exploration activities (as feature selection) in a more
#' autonomic way. This R package is implemented as open-source software
#' and offered to the R community for use and improvement.
#'
#' @details
#'
#' There are multiple methodologies proposed for the development of AI pipelines
#' in industrial environments, and all of them include a "Data Exploration"
#' phase in which the treatment of outlier data, the analysis of correlations
#' and feature extraction/selection (amongs others) are carried out. Functions
#' included in this package are focus to perform "Data cleaning",
#' "Data Normalization" and "Data Reduction" activities in a more self-X way.
#'
#' \strong{self-X autonomic supervised and unsupervised feature selection}
#'
#' Feature Selection in Data Mining is a complementary technique that also
#' helps to reduce the dimensionality of the data on which to subsequently
#' apply the modelling algorithms, i.e., to enhance the quality and efficiency
#' of clustering and/or predictive models, enabling them to focus on the most
#' relevant and significant features for the given problem. In this way, the
#' quality of the results is improved, their visualization and interpretation
#' is facilitated, and the problems associated with high-dimensional data sets
#' are alleviated.
#'
#' With the aim of making feature selection more autonomic, an ad-hoc procedure
#' was defined as part of the Asphalt Use Case within the s-X-AIPI project and
#' subsequently adapted for general use.
#'
#' The approach can be summarized as follows:
#' \itemize{
#'     \item Initially, well-known techniques (PCA/FA for unsupervised and
#'     RELIEF for supervised approaches) are used to select the most important
#'     features under different criteria.
#'     \item Subsequently, an OWA operator is applied to select the three most
#'     relevant ones.
#' }
#'
#' \emph{The s-X-AIPI project has received funding from the European Union's Horizon
#' Europe research and innovation programme under grant agreement Nº 101058715
#' (\url{https://s-x-aipi-project.eu/})}
#'
#' @keywords package selfX s-X-AIPI autonomic data exploration
#' @encoding UTF-8
#' @encoding Latin-1
#' @author Marta Galende-Hernández \email{margal@@cartif.es},
#'
#' and Antonio Corral \email{antcor@@cartif.es},
#'
#' Industrial and Digital Systems Division, Fundación CARTIF.
#'
#' \url{https://s-x-aipi-project.eu/}, \url{https://www.cartif.es}
#'
## usethis namespace: start
#' @import foreach
## usethis namespace: end
NULL
